orgmode

search
El Cato

Welcome to the docs for El Cato static block generator

Chat - Matrix Software - GitLab
ElCato Static Blogging Platform
ElCato Static Blogging Platform

Static blog generator

Org Markup Advanced Reference
Org Markup Advanced Reference

Quick show case to more advanced markup in org mode

Org Markup Quick Reference
Org Markup Quick Reference

Quick reference guide to markup in org mode

rss_feed